Author: duncan
Date: Sat Oct 21 10:07:55 2006
New Revision: 8440

Modified:
   branches/rel-1/freevo/setup.py
   branches/rel-1/freevo/src/audio/audiodiskitem.py
   branches/rel-1/freevo/src/audio/audioitem.py
   branches/rel-1/freevo/src/audio/plugins/cdbackup.py
   branches/rel-1/freevo/src/directory.py
   branches/rel-1/freevo/src/encodingcore.py
   branches/rel-1/freevo/src/helpers/cache.py
   branches/rel-1/freevo/src/image/__init__.py
   branches/rel-1/freevo/src/image/imageitem.py
   branches/rel-1/freevo/src/main.py
   branches/rel-1/freevo/src/plugins/rom_drives.py
   branches/rel-1/freevo/src/skins/main/skin_utils.py
   branches/rel-1/freevo/src/util/dbutil.py
   branches/rel-1/freevo/src/util/extendedmeta.py
   branches/rel-1/freevo/src/util/fileops.py
   branches/rel-1/freevo/src/util/fxdimdb.py
   branches/rel-1/freevo/src/util/mediainfo.py
   branches/rel-1/freevo/src/util/misc.py
   branches/rel-1/freevo/src/util/videothumb.py
   branches/rel-1/freevo/src/video/configure.py
   branches/rel-1/freevo/src/video/plugins/bmovl.py
   branches/rel-1/freevo/src/video/plugins/bookmarker.py
   branches/rel-1/freevo/src/video/plugins/mplayer.py
   branches/rel-1/freevo/src/video/plugins/reencode.py
   branches/rel-1/freevo/src/video/videoitem.py

Log:
[ 1580712 ] Replace mmpython with kaa.base and kaa.metadata
Update applied


Modified: branches/rel-1/freevo/setup.py
==============================================================================
--- branches/rel-1/freevo/setup.py      (original)
+++ branches/rel-1/freevo/setup.py      Sat Oct 21 10:07:55 2006
@@ -18,7 +18,8 @@
 
 check_libs((
             ('xml.utils.qp_xml', 'http://pyxml.sourceforge.net/'),
-            ('mmpython', 'http://www.sf.net/projects/mmpython' ),
+            ('kaa', 'http://sourceforge.net/projects/kaa' ),
+            ('kaa.metadata', 'http://sourceforge.net/projects/kaa' ),
             ('pygame', 'http://www.pygame.org'),
             ('Image', 'http://www.pythonware.com/products/pil/'),
             ('elementtree', 'http://effbot.org/zone/elementtree.htm'),

Modified: branches/rel-1/freevo/src/audio/audiodiskitem.py
==============================================================================
--- branches/rel-1/freevo/src/audio/audiodiskitem.py    (original)
+++ branches/rel-1/freevo/src/audio/audiodiskitem.py    Sat Oct 21 10:07:55 2006
@@ -8,14 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.30  2004/07/10 12:33:37  dischi
-# header cleanup
-#
-# Revision 1.29  2004/01/25 14:55:05  dischi
-# use overlay dir for covers
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2003 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -34,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import config

Modified: branches/rel-1/freevo/src/audio/audioitem.py
==============================================================================
--- branches/rel-1/freevo/src/audio/audioitem.py        (original)
+++ branches/rel-1/freevo/src/audio/audioitem.py        Sat Oct 21 10:07:55 2006
@@ -8,42 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.57.2.2  2004/09/10 19:48:17  outlyer
-# Fix sorting behaviour to respect rather than ignore TPOS tags. This is the
-# expected behaviour, but was missing. Requires latest mmpython to work 
properly.
-#
-# Revision 1.57.2.1  2004/07/21 17:12:23  outlyer
-# Bugfix.
-#
-# Revision 1.57  2004/07/17 08:18:55  dischi
-# unicode fixes
-#
-# Revision 1.56  2004/07/10 13:36:07  outlyer
-# Handle the situation where track number can't be converted into an int()
-#
-# Revision 1.55  2004/07/10 12:33:37  dischi
-# header cleanup
-#
-# Revision 1.54  2004/06/25 23:11:43  outlyer
-# Fix the advanced sort. Since 'trackno' is a number, but the sort is 
alphabetical,
-# we pad the numbers with 0's to make it sort properly. Fixed my problem with
-# '9' showing up at the end of the list.
-#
-# For some reason, it's still returning
-# 01
-# 02
-# 03
-# 04
-# 05
-# 06
-# 07
-# 08
-# 9
-# 10
-# 11
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -62,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import os

Modified: branches/rel-1/freevo/src/audio/plugins/cdbackup.py
==============================================================================
--- branches/rel-1/freevo/src/audio/plugins/cdbackup.py (original)
+++ branches/rel-1/freevo/src/audio/plugins/cdbackup.py Sat Oct 21 10:07:55 2006
@@ -27,21 +27,6 @@
 # very well.
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.33.2.3  2004/08/28 17:08:32  dischi
-# fix crash in debug
-#
-# Revision 1.33.2.1  2004/08/04 21:33:35  outlyer
-# Bugfix for Ogg ripping, reported by Nicolas Michaux
-#
-# Revision 1.33  2004/07/10 12:33:37  dischi
-# header cleanup
-#
-# Revision 1.32  2004/05/28 20:23:19  dischi
-# o Fix bug when AlertBox has no input focus
-# o Make it possible to abort a ripping session
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al.
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -60,7 +45,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import os
@@ -84,7 +69,7 @@
 from util import popen3
 
 # Included to be able to access the info for Audio CDs
-import mmpython
+import kaa.metadata as mmpython
 
 class PluginInterface(plugin.ItemPlugin):
     """

Modified: branches/rel-1/freevo/src/directory.py
==============================================================================
--- branches/rel-1/freevo/src/directory.py      (original)
+++ branches/rel-1/freevo/src/directory.py      Sat Oct 21 10:07:55 2006
@@ -8,14 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.132  2004/07/10 12:33:36  dischi
-# header cleanup
-#
-# Revision 1.131  2004/06/10 09:19:12  dischi
-# only remove start strings => 10
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -34,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import os

Modified: branches/rel-1/freevo/src/encodingcore.py
==============================================================================
--- branches/rel-1/freevo/src/encodingcore.py   (original)
+++ branches/rel-1/freevo/src/encodingcore.py   Sat Oct 21 10:07:55 2006
@@ -33,7 +33,7 @@
 from time import sleep
 import sys, os, re, popen2 #, ConfigParser, copy
 import config
-import mmpython
+import kaa.metadata as mmpython
 from copy import copy
 from string import split, join
 

Modified: branches/rel-1/freevo/src/helpers/cache.py
==============================================================================
--- branches/rel-1/freevo/src/helpers/cache.py  (original)
+++ branches/rel-1/freevo/src/helpers/cache.py  Sat Oct 21 10:07:55 2006
@@ -10,26 +10,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.38  2004/07/21 11:33:34  dischi
-# support one file thumbnailing
-#
-# Revision 1.37  2004/07/10 12:33:39  dischi
-# header cleanup
-#
-# Revision 1.36  2004/06/06 08:31:37  dischi
-# fix crash
-#
-# Revision 1.35  2004/06/06 06:41:47  dischi
-# delete cache on mmpython update
-#
-# Revision 1.34  2004/05/12 20:07:01  dischi
-# do not delete raw files for discs
-#
-# Revision 1.33  2004/05/02 11:46:13  dischi
-# make it possible to turn off image caching
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -48,7 +28,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import sys
@@ -403,7 +383,7 @@
     else:
         rebuild = 0
     try:
-        import mmpython.version
+        import kaa.metadata.version
 
         info = None
         cachefile = os.path.join(config.FREEVO_CACHEDIR, 'mediainfo')
@@ -422,16 +402,16 @@
                 mmchanged, freevo_changed, part_update, complete_update = info
 
             # let's warn about some updates
-            if freevo_changed < VERSION or mmpython.version.CHANGED > 
mmchanged:
+            if freevo_changed < VERSION or kaa.metadata.version.CHANGED > 
mmchanged:
                 print 'Cache too old, forcing rebuild'
                 rebuild = 2
                 complete_update = int(time.time())
                 
     except ImportError:
         print
-        print 'Error: unable to read mmpython version information'
-        print 'Please update mmpython to the latest release or if you use'
-        print 'Freevo CVS versions, please also use mmpython CVS.'
+        print 'Error: unable to read kaa.metadata version information'
+        print 'Please update kaa.metadata to the latest release or if you use'
+        print 'Freevo SVN versions, please also use kaa.metadata SVN.'
         print
         print 'Some functions in Freevo may not work or even crash!'
         print
@@ -473,11 +453,11 @@
 
 # save cache info
 try:
-    import mmpython.version
-    util.save_pickle((mmpython.version.CHANGED, VERSION,
+    import kaa.metadata.version
+    util.save_pickle((kaa.metadata.version.CHANGED, VERSION,
                       int(time.time()), complete_update), cachefile)
 except ImportError:
-    print 'WARNING: please update mmpython'
+    print 'WARNING: please update kaa.metadata'
 
 print
 print 'caching complete after %s seconds' % (time.clock() - start)

Modified: branches/rel-1/freevo/src/image/__init__.py
==============================================================================
--- branches/rel-1/freevo/src/image/__init__.py (original)
+++ branches/rel-1/freevo/src/image/__init__.py Sat Oct 21 10:07:55 2006
@@ -31,8 +31,8 @@
 
 import os
 
-# Add support for bins album files
-from mmpython.image import bins
+# Add support for bins album files (http://bins.sautret.org/)
+import kaa.metadata.misc.dirinfo as bins
 
 import config
 import util
@@ -78,19 +78,17 @@
         """
         set informations for a diritem based on album.xml
         """
-        if vfs.isfile(diritem.dir + '/album.xml'):
-            info  = bins.get_bins_desc(diritem.dir)
-            if not info.has_key('desc'):
-                return
-
-            info = info['desc']
-            if info.has_key('sampleimage') and info['sampleimage']:
-                image = vfs.join(diritem.dir, info['sampleimage'])
-                if vfs.isfile(image):
-                    diritem.image       = image
+        dirinfo  = bins.DirInfo(diritem.dir)
+        if dirinfo.has_key('desc'):
+            info = dirinfo['desc']
+
+        if dirinfo.has_key('sampleimage') and dirinfo['sampleimage']:
+            image = vfs.join(diritem.dir, dirinfo['sampleimage'])
+            if vfs.isfile(image):
+                diritem.image = image
 
-            if info.has_key('title') and info['title']:
-                diritem.name = info['title']
+        if dirinfo.has_key('title') and dirinfo['title']:
+            diritem.name = dirinfo['title']
 
 
     def fxdhandler(self, fxd, node):

Modified: branches/rel-1/freevo/src/image/imageitem.py
==============================================================================
--- branches/rel-1/freevo/src/image/imageitem.py        (original)
+++ branches/rel-1/freevo/src/image/imageitem.py        Sat Oct 21 10:07:55 2006
@@ -32,7 +32,7 @@
 import util
 import os
 import time
-import mmpython
+import kaa.metadata as mmpython
 
 import config
 import viewer

Modified: branches/rel-1/freevo/src/main.py
==============================================================================
--- branches/rel-1/freevo/src/main.py   (original)
+++ branches/rel-1/freevo/src/main.py   Sat Oct 21 10:07:55 2006
@@ -8,26 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.129  2004/07/10 12:33:36  dischi
-# header cleanup
-#
-# Revision 1.128  2004/06/29 18:48:49  dischi
-# prepare for 1.5.0-rc4
-#
-# Revision 1.127  2004/06/20 15:52:14  dischi
-# set umask as early as possible
-#
-# Revision 1.126  2004/06/06 10:31:42  dischi
-# make it possible to shut down freevo on crash
-#
-# Revision 1.125  2004/06/06 08:31:15  dischi
-# check for mmpython version
-#
-# Revision 1.124  2004/06/06 07:45:35  dischi
-# check for numeric
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -46,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 # Must do this here to make sure no os.system() calls generated by module init
@@ -87,7 +67,7 @@
     else:
         os.environ['LSDVD'] = config.CONF.lsdvd
         
-    import mmpython
+    import kaa.metadata as mmpython
 
     
 except ImportError, i:

Modified: branches/rel-1/freevo/src/plugins/rom_drives.py
==============================================================================
--- branches/rel-1/freevo/src/plugins/rom_drives.py     (original)
+++ branches/rel-1/freevo/src/plugins/rom_drives.py     Sat Oct 21 10:07:55 2006
@@ -8,23 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.63.2.2  2005/01/23 11:40:19  dischi
-# small patch when there are directories on a disc
-#
-# Revision 1.63.2.1  2004/08/28 17:09:34  dischi
-# force rechecking if it seems a dvd but is not detected as one
-#
-# Revision 1.63  2004/07/10 12:33:40  dischi
-# header cleanup
-#
-# Revision 1.62  2004/06/20 13:06:19  dischi
-# move freevo-rebuild-database to cache dir
-#
-# Revision 1.61  2004/05/25 17:35:29  dischi
-# make nicer title for discs
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -43,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import time, os

Modified: branches/rel-1/freevo/src/skins/main/skin_utils.py
==============================================================================
--- branches/rel-1/freevo/src/skins/main/skin_utils.py  (original)
+++ branches/rel-1/freevo/src/skins/main/skin_utils.py  Sat Oct 21 10:07:55 2006
@@ -36,7 +36,7 @@
 import osd
 import os
 import util
-from mmpython.image import EXIF as exif
+from kaa.metadata.image import EXIF as exif
 
 osd = osd.get_singleton()
 

Modified: branches/rel-1/freevo/src/util/dbutil.py
==============================================================================
--- branches/rel-1/freevo/src/util/dbutil.py    (original)
+++ branches/rel-1/freevo/src/util/dbutil.py    Sat Oct 21 10:07:55 2006
@@ -8,17 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.6  2004/07/10 12:33:42  dischi
-# header cleanup
-#
-# Revision 1.5  2004/02/07 13:07:55  dischi
-# fix unicode/encoding problem with sqlite
-#
-# Revision 1.4  2004/02/01 16:58:34  rshortt
-# Catch some exceptions probably having to do with bad data.
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -37,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import os, traceback

Modified: branches/rel-1/freevo/src/util/extendedmeta.py
==============================================================================
--- branches/rel-1/freevo/src/util/extendedmeta.py      (original)
+++ branches/rel-1/freevo/src/util/extendedmeta.py      Sat Oct 21 10:07:55 2006
@@ -8,14 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.13  2004/07/10 12:33:42  dischi
-# header cleanup
-#
-# Revision 1.12  2004/05/29 12:32:23  dischi
-# try to find out if all items in a dir belong to one album
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -34,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 # The basics
@@ -51,7 +43,7 @@
 except ImportError:
     pass
     
-from mmpython.audio import eyeD3
+from kaa.metadata.audio import eyeD3
 from util import recursefolders
 
 ##### Database

Modified: branches/rel-1/freevo/src/util/fileops.py
==============================================================================
--- branches/rel-1/freevo/src/util/fileops.py   (original)
+++ branches/rel-1/freevo/src/util/fileops.py   Sat Oct 21 10:07:55 2006
@@ -8,26 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.25.2.1  2005/01/16 11:08:27  dischi
-# ignore bad subdirs
-#
-# Revision 1.25  2004/07/10 12:33:42  dischi
-# header cleanup
-#
-# Revision 1.24  2004/07/04 08:04:21  dischi
-# handle PIL exception
-#
-# Revision 1.23  2004/06/29 18:08:56  dischi
-# use vfs.open to make sure we can write
-#
-# Revision 1.22  2004/06/21 12:00:56  dischi
-# wrap exif call inside the try except
-#
-# Revision 1.21  2004/06/13 18:49:39  dischi
-# do not take care of install.py
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -46,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import os
@@ -62,7 +42,7 @@
 # image stuff
 import Image
 import cStringIO
-from mmpython.image import EXIF as exif
+from kaa.metadata.image import EXIF as exif
 
 
 if float(sys.version[0:3]) < 2.3:

Modified: branches/rel-1/freevo/src/util/fxdimdb.py
==============================================================================
--- branches/rel-1/freevo/src/util/fxdimdb.py   (original)
+++ branches/rel-1/freevo/src/util/fxdimdb.py   Sat Oct 21 10:07:55 2006
@@ -10,17 +10,6 @@
 # - webradio support?
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.7.2.1  2005/01/09 10:29:17  dischi
-# make imdb work again
-#
-# Revision 1.7  2004/07/10 12:33:42  dischi
-# header cleanup
-#
-# Revision 1.6  2004/06/20 13:06:20  dischi
-# move freevo-rebuild-database to cache dir
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2003 Krister Lagerstrom, et al.
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -39,7 +28,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 # python has no data hiding, but this is the intended use...
@@ -62,7 +51,7 @@
 import config 
 import util
 
-from mmpython.disc.discinfo import cdrom_disc_id
+from kaa.metadata.disc.discinfo import cdrom_disc_id
 #Constants
 
 freevo_version = '1.3.4'

Modified: branches/rel-1/freevo/src/util/mediainfo.py
==============================================================================
--- branches/rel-1/freevo/src/util/mediainfo.py (original)
+++ branches/rel-1/freevo/src/util/mediainfo.py Sat Oct 21 10:07:55 2006
@@ -8,29 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.55.2.1  2004/08/28 17:09:41  dischi
-# force rechecking if it seems a dvd but is not detected as one
-#
-# Revision 1.55  2004/07/11 10:05:14  dischi
-# fix crash for bad discs
-#
-# Revision 1.54  2004/07/10 12:33:42  dischi
-# header cleanup
-#
-# Revision 1.53  2004/07/09 14:34:52  dischi
-# inverse the rc.app() call. One line, two bugs :-(
-#
-# Revision 1.52  2004/07/09 14:33:05  dischi
-# bugfix: rc.app is always true, it is rc.app() we want
-#
-# Revision 1.51  2004/07/08 14:37:47  dischi
-# prevent crash for bad pickle results
-#
-# Revision 1.50  2004/06/29 18:07:03  dischi
-# reload cache if cache helper runs while running freevo
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -49,14 +26,14 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import os, stat
 import sys
 import copy
 
-import mmpython
+import kaa.metadata as mmpython
 from mmpython.disc.discinfo import cdrom_disc_id
 
 import config

Modified: branches/rel-1/freevo/src/util/misc.py
==============================================================================
--- branches/rel-1/freevo/src/util/misc.py      (original)
+++ branches/rel-1/freevo/src/util/misc.py      Sat Oct 21 10:07:55 2006
@@ -8,33 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.44.2.1  2004/08/28 17:10:16  dischi
-# prevent crash
-#
-# Revision 1.44  2004/07/11 19:33:35  dischi
-# make mass storage only storage to cover all forms
-#
-# Revision 1.43  2004/07/11 18:43:52  dischi
-# fix usb storage detection
-#
-# Revision 1.42  2004/07/11 11:46:03  dischi
-# decrease record server calling
-#
-# Revision 1.41  2004/07/10 12:33:42  dischi
-# header cleanup
-#
-# Revision 1.40  2004/07/04 08:10:50  dischi
-# make sure upsoon is written
-#
-# Revision 1.39  2004/06/23 20:29:42  dischi
-# fix typo in hasattr
-#
-# Revision 1.38  2004/06/23 12:11:59  outlyer
-# Apparently TvProgram instances without a sub_title no longer define that
-# property anymore, so make sure it exists before trying to access it.
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -53,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import glob
@@ -350,12 +323,12 @@
 def tagmp3 (filename, title=None, artist=None, album=None, track=None,
             tracktotal=None, year=None):
     """
-    use eyeD3 directly from inside mmpython to
+    use eyeD3 directly from inside mkka.metadata to
     set the tag. We default to 2.3 since even
     though 2.4 is the accepted standard now, more
     players support 2.3
     """
-    import mmpython.audio.eyeD3 as eyeD3   # Until mmpython has an interface 
for this.
+    import kaa.metadata.audio.eyeD3 as eyeD3
 
     tag = eyeD3.Tag(String(filename))
     tag.header.setVersion(eyeD3.ID3_V2_3)

Modified: branches/rel-1/freevo/src/util/videothumb.py
==============================================================================
--- branches/rel-1/freevo/src/util/videothumb.py        (original)
+++ branches/rel-1/freevo/src/util/videothumb.py        Sat Oct 21 10:07:55 2006
@@ -12,23 +12,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.14  2004/07/21 11:34:31  dischi
-# only import config/vfs when needed
-#
-# Revision 1.13  2004/07/10 12:33:42  dischi
-# header cleanup
-#
-# Revision 1.12  2004/07/08 11:03:02  dischi
-# use .tmp filename and new freevo raw format
-#
-# Revision 1.11  2004/06/23 21:09:29  dischi
-# handle mplayer TS, PES problems
-#
-# Revision 1.10  2004/05/02 09:21:57  dischi
-# better python code
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -47,10 +30,11 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
-import sys, os, mmpython, glob, shutil
+import sys, os, glob, shutil
+import kaa.metadata as mmpython
 from stat import *
 
 def snapshot(videofile, imagefile=None, pos=None, update=True, popup=None):

Modified: branches/rel-1/freevo/src/video/configure.py
==============================================================================
--- branches/rel-1/freevo/src/video/configure.py        (original)
+++ branches/rel-1/freevo/src/video/configure.py        Sat Oct 21 10:07:55 2006
@@ -8,24 +8,6 @@
 # Todo:  Fix some stuff, wait for the mplayer people what they are doing
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.27.2.1  2004/08/28 17:11:54  dischi
-# use chapter selection to select file for multi file videos
-#
-# Revision 1.27  2004/07/10 12:33:43  dischi
-# header cleanup
-#
-# Revision 1.26  2004/05/28 15:50:27  dischi
-# configure menu items cleanup
-# support chapters as ChapterInfo in mmpython (e.g. ogm files)
-#
-# Revision 1.25  2004/05/06 18:12:17  dischi
-# fix crash
-#
-# Revision 1.24  2004/03/13 23:44:02  dischi
-# audio stream selection fixes
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -44,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 # The menu widget class

Modified: branches/rel-1/freevo/src/video/plugins/bmovl.py
==============================================================================
--- branches/rel-1/freevo/src/video/plugins/bmovl.py    (original)
+++ branches/rel-1/freevo/src/video/plugins/bmovl.py    Sat Oct 21 10:07:55 2006
@@ -8,40 +8,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.16  2004/07/17 08:56:12  dischi
-# fix typo in variable
-#
-# Revision 1.15  2004/07/16 19:39:00  dischi
-# smaller cleanups, still alpha
-#
-# Revision 1.14  2004/07/11 19:39:47  dischi
-# reflect mmpython changes
-#
-# Revision 1.13  2004/07/10 12:33:43  dischi
-# header cleanup
-#
-# Revision 1.12  2004/07/10 10:36:53  dischi
-# fix more crashes
-#
-# Revision 1.11  2004/07/10 08:44:20  dischi
-# fix crash
-#
-# Revision 1.10  2004/07/09 21:12:18  dischi
-# more bmovl fixes, still unstable
-#
-# Revision 1.9  2004/07/08 19:30:54  dischi
-# o make some changes to make it look better
-# o secure write with try except
-# o add warning that this plugin is not stable
-#
-# Revision 1.8  2004/01/11 20:23:31  dischi
-# move skin font handling to osd to avoid duplicate code
-#
-# Revision 1.7  2004/01/11 20:01:28  dischi
-# make bmovl work again
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -60,7 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import os

Modified: branches/rel-1/freevo/src/video/plugins/bookmarker.py
==============================================================================
--- branches/rel-1/freevo/src/video/plugins/bookmarker.py       (original)
+++ branches/rel-1/freevo/src/video/plugins/bookmarker.py       Sat Oct 21 
10:07:55 2006
@@ -19,14 +19,6 @@
 #
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.12  2004/07/10 12:33:43  dischi
-# header cleanup
-#
-# Revision 1.11  2004/02/22 20:33:48  dischi
-# some unicode fixes
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -45,11 +37,11 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import os, time, copy
-import mmpython
+import kaa.metadata as mmpython
 
 import plugin
 import config

Modified: branches/rel-1/freevo/src/video/plugins/mplayer.py
==============================================================================
--- branches/rel-1/freevo/src/video/plugins/reencode.py (original)
+++ branches/rel-1/freevo/src/video/plugins/reencode.py Sat Oct 21 10:07:55 2006
@@ -1,13 +1,12 @@
-#!/usr/bin/env python
 # -*- coding: iso-8859-1 -*-
 # -----------------------------------------------------------------------
 # re-encode recorded TV programmes
 # -----------------------------------------------------------------------
-# $Id: encode.py $
+# $Id: reencode.py $
 #
 # Notes:
 #    To activate, put the following line in local_conf.py:
-#       plugin.activate('tv.encode')
+#       plugin.activate('video.reencode')
 # ToDo:        
 #
 # -----------------------------------------------------------------------

Modified: branches/rel-1/freevo/src/video/videoitem.py
==============================================================================
--- branches/rel-1/freevo/src/video/videoitem.py        (original)
+++ branches/rel-1/freevo/src/video/videoitem.py        Sat Oct 21 10:07:55 2006
@@ -9,53 +9,6 @@
 # Todo:        
 #
 # -----------------------------------------------------------------------
-# $Log$
-# Revision 1.144.2.3  2005/01/20 16:36:06  dischi
-# fix crash
-#
-# Revision 1.144.2.2  2004/10/20 18:33:20  dischi
-# fix aspect ration crash when it is an int
-#
-# Revision 1.144.2.1  2004/08/28 17:12:23  dischi
-# fix multiple files in one video when replaying
-#
-# Revision 1.144  2004/07/21 11:34:59  dischi
-# disable one track auto-play for dvd
-#
-# Revision 1.143  2004/07/17 08:18:56  dischi
-# unicode fixes
-#
-# Revision 1.142  2004/07/11 10:22:28  dischi
-# fix bug for auto joined files on disc
-#
-# Revision 1.141  2004/07/11 10:14:12  dischi
-# reset current_subitem on play start
-#
-# Revision 1.140  2004/07/10 12:33:43  dischi
-# header cleanup
-#
-# Revision 1.139  2004/07/04 08:05:13  dischi
-# auto deinterlace mpeg files
-#
-# Revision 1.138  2004/06/23 12:22:16  outlyer
-# Allow the user to create a thumbnail for a file even if a folder or file
-# image already exists. For example, I have a generic "cover.jpg" in my
-# movie folder, but I will occaisonally use the thumbnailing for a file in
-# that directory. This 'if' clause prevents that from being possible.
-#
-# Revision 1.137  2004/05/29 13:10:55  dischi
-# re-use string for better translation
-#
-# Revision 1.136  2004/05/28 15:50:28  dischi
-# configure menu items cleanup
-# support chapters as ChapterInfo in mmpython (e.g. ogm files)
-#
-# Revision 1.135  2004/05/13 13:49:24  outlyer
-# The much appreciated 'alternate player' patch from den_RDC. Allows you to
-# switch between your default player and an alternate without restarting
-# Freevo.
-#
-# -----------------------------------------------------------------------
 # Freevo - A Home Theater PC framework
 # Copyright (C) 2002 Krister Lagerstrom, et al. 
 # Please see the file freevo/Docs/CREDITS for a complete list of authors.
@@ -74,7 +27,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# ----------------------------------------------------------------------- */
+# -----------------------------------------------------------------------
 
 
 import os

-------------------------------------------------------------------------
Using Tomcat but need to do more? Need to support web services, security?
Get stuff done quickly with pre-integrated technology to make your job easier
Download IBM WebSphere Application Server v.1.0.1 based on Apache Geronimo
http://sel.as-us.falkag.net/sel?cmd=lnk&kid=120709&bid=263057&dat=121642
_______________________________________________
Freevo-cvslog mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/freevo-cvslog

Reply via email to
--- branches/rel-1/freevo/src/video/plugins/mplayer.py  (original)
+++ branches/rel-1/freevo/src/video/plugins/mplayer.py  Sat Oct 21 10:07:55 2006
@@ -32,7 +32,7 @@
 import os, re
 import threading
 import popen2
-import mmpython
+import kaa.metadata as mmpython
 
 import config     # Configuration handler. reads config file.
 import util       # Various utilities
@@ -89,6 +89,10 @@
         if item.mode in ('dvd', 'vcd'):
             return 2
         if item.mimetype in config.VIDEO_MPLAYER_SUFFIX:
+            for d in dir(item):
+                print '%s: %s' % (d, eval('item.%s' % d))
+            for d in dir(item.info):
+                print '%s: %s' % (d, eval('item.info.%s' % d))
             return 2
         if item.network_play:
             return 1
@@ -185,18 +189,17 @@
         if item.selected_audio != None:
             additional_args += [ '-aid', str(item.selected_audio) ]
 
-        if item['deinterlace']:
-            additional_args += [ '-vf',  config.MPLAYER_VF_INTERLACED ]
-        else:
-            additional_args += [ '-vf',  config.MPLAYER_VF_PROGRESSIVE ]
+        if item['deinterlace'] and config.MPLAYER_VF_INTERLACED:
+                additional_args += [ '-vf', config.MPLAYER_VF_INTERLACED ]
+        elif config.MPLAYER_VF_PROGRESSIVE:
+                additional_args += [ '-vf', config.MPLAYER_VF_PROGRESSIVE ]
                 
         mode = item.mimetype
         if not config.MPLAYER_ARGS.has_key(mode):
             mode = 'default'
 
         # Mplayer command and standard arguments
-        command += [ '-v', '-vo', config.MPLAYER_VO_DEV +
-                     config.MPLAYER_VO_DEV_OPTS ]
+        command += [ '-v', '-vo', config.MPLAYER_VO_DEV + 
config.MPLAYER_VO_DEV_OPTS ]
 
         # mode specific args
         command += config.MPLAYER_ARGS[mode].split(' ')
@@ -220,7 +223,7 @@
         elif not '-framedrop' in command:
             command += config.MPLAYER_SOFTWARE_SCALER.split(' ')
 
         # correct avi delay based on mmpython settings
         if config.MPLAYER_SET_AUDIO_DELAY and item.info.has_key('delay') and \
                item.info['delay'] > 0:
             command += [ '-mc', str(int(item.info['delay'])+1), '-delay',
@@ -220,7 +223,7 @@
             command += config.MPLAYER_SOFTWARE_SCALER.split(' ')
 
-        # correct avi delay based on mmpython settings
+        # correct avi delay based on kaa.metadata settings
         if config.MPLAYER_SET_AUDIO_DELAY and item.info.has_key('delay') and \
                item.info['delay'] > 0:

Modified: branches/rel-1/freevo/src/video/plugins/reencode.py
==============================================================================